==> kget_17.12.3.orig.tar.xz: kget-17.12.3/transfer-plugins/metalink/fileselectiondlg.h <==
/***************************************************************************
*   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>                     *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
***************************************************************************/

#ifndef FILESELECTIONDLG_H 
#define FILESELECTIONDLG_H

#include <KDialog>

#include "ui_fileselection.h"

class FileModel;

class FileSelectionDlg : public KDialog
{
    Q_OBJECT

    public:
        FileSelectionDlg(FileModel *model, QWidget *parent = nullptr);

    private:
        Ui::FileSelection ui;
};

#endif

==> kget-22.11.90.tar.xz: kget-22.11.90/transfer-plugins/metalink/fileselectiondlg.h <==
/***************************************************************************
*   Copyright (C) 2010 Matthias Fuchs <mat69@gmx.net>                     *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
***************************************************************************/

#ifndef FILESELECTIONDLG_H 
#define FILESELECTIONDLG_H

#include <QDialog>

#include "ui_fileselection.h"

class FileModel;

class FileSelectionDlg : public QDialog
{
    Q_OBJECT

    public:
        FileSelectionDlg(FileModel *model, QWidget *parent = nullptr);

    private:
        Ui::FileSelection ui;
};

#endif
